********************************************************************************
*																			   *
*					Outlier Identification									   *
*																			   *
********************************************************************************

 *******************************************************************************
 *				Outlier Identification for Model 1 of			
 *				Table 3 In Chen et al. (2004)
 *				Original Sample *
 *******************************************************************************
 
**  Gross Market Adjusted Returns
**  Column 1 in Table 3 of Chen (2004) and Column 5 in Table 1 of our paper

**	Vertical Outlier Identification 
 timer clear
 timer on 1
 ereturn clear
discard
clear 
cd "your file location"
use reggm.dta
sort yr mn
keep if tna_qtl >= 2 & tna_qtl <= 5
drop fam_ltna
gen fam_ltna =ln(fam_tna)
gen fam_xtna=ln(1 + fam_tna-tna)
drop pret 
gen pret = pmret*100 
gen fret =  mret*100 
set matsize 799
gen touse = !missing(fret, pret, mret, ltna, fam_xtna,age, expenses,tot_load, flow) 
keep if touse==1
destring fund, generate(fund2)
gen modate=ym(yr,mn)
tsset fund2 modate

sort modate
egen group = group(modate)
// Compute standardized robust residuals and outliers in each month
// sregress is avauilable on Stats's SSC
drop if group==.
gen outlier_vert=.
gen vertical_distance=.
su group 
local max = r(max) 
 qui forval i = 1/`max' { 
 	sregress fret ltna fam_xtna turnover age expenses tot_load flow pret if group == `i', outlier
	gen temp=S_outlier
	gen temp2=S_stdres
	replace outlier_vert=temp if group == `i'
	replace vertical_distance=temp2 if group ==`i'
	drop temp temp2
 discard
 }
 
 save outliers,replace
 timer off 1 //timers not necessary but included to illustrate computational requirements - expect several hours to run
timer list 1 
  
** Bad Leverage Leverage Outlier Identification
//mcd command beliw is available on Stata's SSC
 timer clear
 timer on 3
 clear
ereturn clear
discard
use outliers
gen outlier_mcd=.
gen lev_mcd=.
 su group
local max = r(max) 
return list
 qui forval i = 1/`max' { 
	mcd fret ltna fam_xtna turnover age expenses tot_load flow pret if group == `i',generate(outlier3 RobustDistance)
	gen temp=outlier3
	gen temp2=RobustDistance
	replace outlier_mcd=temp if group == `i'
	replace lev_mcd=temp2 if group == `i'
	drop temp temp2 outlier3 RobustDistance
	//ereturn clear
	discard
 }
 
save outliers,replace
 timer off 3
timer list 3 
 // Merge outlier metrics into single file and label
 clear
use outliers
 sort fund modate
gen goutlier=0
gen voutlier=0
gen boutlier=0
replace goutlier=1 if outlier_vert==0 & outlier_mcd==1
replace voutlier=1 if outlier_vert==1 & outlier_mcd==0
replace boutlier=1 if outlier_vert==1 & outlier_mcd==1
by modate, sort : egen mean_voutlier=mean(voutlier)
by modate, sort : egen mean_goutlier=mean(goutlier)
by modate, sort : egen mean_boutlier=mean(boutlier)
duplicates drop
sort fund modate
drop  touse group  S_outlier S_stdres 
save outliers,replace

** Outlier size by percentile

clear
use outliers

by modate, sort: egen n = count(lev_mcd)
by modate: egen i = rank(lev_mcd), track 
gen pcrank_lev = (i - 1) / (n - 1)  

drop n i
by modate, sort: egen n = count(vertical_distance)
by modate: egen i = rank(vertical_distance), track 
gen pcrank_vert = (i - 1) / (n - 1)  
drop n i

egen quartile_lev = xtile(lev_mcd), by(modate) n(10)
egen quartile_vert = xtile(vertical_distance), by(modate) n(10)

save outliers,replace
