log using table1

*******************************************************************************************************************
***
***		Adams, Hayunga, and Mansi (2018+) Critique of Chen et al. (2004)
***		Diseconomies of Scale in the Actively-Managed Mutual Fund Industry: 
***		What Do the Outliers in the Data Tell Us?
***
*******************************************************************************************************************

 *******************************************************************************************************************
 *
 *		Our Table 1 - Table 3 In Chen et al. (2004) for Gross Returns (Panel A in our paper)
 * 		Using Fama MacBeth and Fama MacBeth OLS and Robust
 *
 *******************************************************************************************************************
 
 *******************************************************************************************************************
 ***
 ***			Fama MacBeth and Fama MacBeth Robust (we provide code for Fama Macbeth Robust on CFR website)
 ***
 *******************************************************************************************************************
 
 **  Gross Market Adjusted Returns
 **  Column 1 in Table 3
 timer clear
 timer on 1
clear 
cd "your file location"
use reggm.dta //created from Joe Chen's code located on AER website

sort yr mn
 
keep if tna_qtl >= 2 & tna_qtl <= 5  // dropping smallest quintile of fund size
gen fam_ltna =ln(fam_tna) 
gen fam_xtna=ln(1 + fam_tna-tna)
drop pret 
gen pret = pmret*100 //convert to percentage format
gen fret =  mret*100 
  
set matsize 799 //Memory requirement for my computer - you may not need to do this

gen touse = !missing(fret, pret, mret, ltna, fam_xtna,age, expenses,tot_load, flow) 
keep if touse==1 //only keep variables with non-missing data
destring fund, generate(fund2) //formatting
gen modate=ym(yr,mn)
tsset fund2 modate
**  Gross Market Adjusted Returns ORIGINAL SAMPLE with OLS
 **  Column 1 in Table 3 of Chen and Column 5 of Table 1 in our paper.
xtfmb fret ltna fam_xtna turnover age expenses tot_load flow pret , lag(3) //xtfmb is available on Stata SSC

**  Gross Market Adjusted Returns Original sample  USING ROBUST REGRESSION   ******
 **  Column 9 in our Table 1
xtfmb_sreg fret ltna fam_xtna turnover age expenses tot_load flow pret, lag(3) //We provide code for xtfmb_sreg on CFR website.

timer off 1
timer list 1  //timers here to illustrate computationally intensive nature of robust regressions
  
**  Beta Adjusted Gross Returns  - Column 6 and 10 in our Table 1

clear 
timer on 2
use reggm.dta
sort yr mn
//keep if yr>1972
//keep if yr<1975
  
keep if tna_qtl >= 2 & tna_qtl <= 5
drop fam_ltna
gen fam_ltna =ln(fam_tna)
gen fam_xtna=ln(1 + fam_tna-tna)
drop pret 
gen pret = palpha0*100 
gen fret =  alpha0*100 
  
set matsize 799
gen touse = !missing(fret, pret, mret, ltna, fam_xtna,age, expenses,tot_load, flow) 
keep if touse==1
destring fund, generate(fund2)
gen modate=ym(yr,mn)
tsset fund2 modate
**  Beta Adjusted GROSS  Returns ORGINAL SAMPLE
**  Column 6 in Table 1
xtfmb fret ltna fam_xtna turnover age expenses tot_load flow pret, lag(3)
**  Beta Adjusted GROSS Returns
 **  Column 10 in Table 1 using robust regression
xtfmb_sreg fret ltna fam_xtna turnover age expenses tot_load flow pret, lag(3)

timer off 2
timer list 2

***  3 Factor Gross Returns
 **  Columns 7 and 11 in Table 1

clear 
timer on 3
use reggm.dta
sort yr mn
keep if tna_qtl >= 2 & tna_qtl <= 5

drop fam_ltna
gen fam_ltna =ln(fam_tna)
gen fam_xtna=ln(1 + fam_tna-tna)
drop pret 
gen pret = palpha1*100 
gen fret =  alpha1*100 
  
set matsize 799
gen touse = !missing(fret, pret, mret, ltna, fam_xtna,age, expenses,tot_load, flow) 
keep if touse==1
destring fund, generate(fund2)
gen modate=ym(yr,mn)
tsset fund2 modate
 **  3 Factor Gross Returns
 **  Column 7 in Table 1
xtfmb fret ltna fam_xtna turnover age expenses tot_load flow pret, lag(3)
**  Column 11 in Table 1 using robust regression!
xtfmb_sreg fret ltna fam_xtna turnover age expenses tot_load flow pret, lag(3)

timer off 3
timer list 3
 
*****   4 Factor Gross Returns  ****
** Column 8 and 12 in Table 1  ****
clear 
timer on 4
use reggm.dta
sort yr mn
 
keep if tna_qtl >= 2 & tna_qtl <= 5

drop fam_ltna
gen fam_ltna =ln(fam_tna)
gen fam_xtna=ln(1 + fam_tna-tna)
drop pret 
gen pret = palpha2*100 
gen fret =  alpha2*100 
  
set matsize 799
gen touse = !missing(fret, pret, mret, ltna, fam_xtna,age, expenses,tot_load, flow) 
keep if touse==1
destring fund, generate(fund2)
gen modate=ym(yr,mn)
tsset fund2 modate
 **  4-FACTOR Gross Returns
 **  Column 8 in Table 1
xtfmb fret ltna fam_xtna turnover age expenses tot_load flow pret, lag(3)
 **  Column 12 in Table 1 using robust regression
xtfmb_sreg fret ltna fam_xtna turnover age expenses tot_load flow pret, lag(3)

timer off 4
timer list 4
//note: outlier p-values in columns 5-8 in Table 1 are generated using the hausman option in Stata program 'robreg' available on SSC.
